PDOInterface class abstract

PDO defines a lightweight, consistent interface for accessing databases provides a data-access abstraction layer

Inheritance

Constructors

PDOInterface()

Properties

config PDOConfig
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pdoInstance PDOInterface
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future
connect() Future<PDOInterface>
execute(String statement, [int? timeoutInSeconds]) Future<int>
Executa uma instrução SQL e retornar o número de linhas afetadas
inherited
getConfig() PDOConfig
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String query, [dynamic params, int? timeoutInSeconds]) Future<PDOResults>
inherited
runInTransaction<T>(Future<T> operation(PDOExecutionContext ctx), [int? timeoutInSeconds]) Future<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited